@@ -26,7 +26,6 @@
 // This file contains the unit tests for the KmlFile class.
 
 #include "kml/engine/kml_file.h"
-#include <string>
 #include "kml/base/file.h"
 #include "kml/base/net_cache.h"
 #include "kml/base/tempfile.h"
@@ -57,8 +56,8 @@ namespace kmlengine {
 class KmlFileTest : public testing::Test {
  protected:
   void VerifyIsPlacemarkWithName(const ElementPtr& root,
-                                 const std::string& name);
-  void KmlToKmz(const std::string& kml_data, std::string* kmz_data);
+                                 const string& name);
+  void KmlToKmz(const string& kml_data, string* kmz_data);
 
   KmlFilePtr kml_file_;
 };
@@ -67,14 +66,14 @@ class KmlFileTest : public testing::Test {
 TEST_F(KmlFileTest, TestEncoding) {
   kml_file_ = KmlFile::CreateFromParse("<kml/>", NULL);
   ASSERT_TRUE(kml_file_);
-  ASSERT_EQ(std::string("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"),
+  ASSERT_EQ(string("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"),
             kml_file_->CreateXmlHeader());
 
-  const std::string kIso_8859_1("iso-8859-1");
+  const string kIso_8859_1("iso-8859-1");
   kml_file_->set_encoding(kIso_8859_1);
   ASSERT_EQ(kIso_8859_1, kml_file_->get_encoding());
 
-  ASSERT_EQ(std::string("<?xml version=\"1.0\" encoding=\"iso-8859-1\"?>\n"),
+  ASSERT_EQ(string("<?xml version=\"1.0\" encoding=\"iso-8859-1\"?>\n"),
             kml_file_->CreateXmlHeader());
 }
 
@@ -88,7 +87,7 @@ TEST_F(KmlFileTest, TestBasicParseFromString) {
   ASSERT_TRUE(root);
   ASSERT_EQ(kmldom::Type_kml, root->Type());
 
-  std::string errors;
+  string errors;
   kml_file_ = KmlFile::CreateFromParse("bad stuff", &errors);
   ASSERT_FALSE(kml_file_);
   ASSERT_FALSE(errors.empty());
@@ -121,8 +120,8 @@ TEST_F(KmlFileTest, TestBasicObjectIdParse) {
 }
 
 TEST_F(KmlFileTest, TestObjectIdDupePassing) {
-  std::string errors;
-  const std::string kDupeId("DUPE");
+  string errors;
+  const string kDupeId("DUPE");
   kml_file_ = KmlFile::CreateFromParse(
     "<Folder id=\"" + kDupeId + "\">"
     "<Placemark id=\"" + kDupeId + "\"/>"
@@ -137,8 +136,8 @@ TEST_F(KmlFileTest, TestObjectIdDupePassing) {
 // TODO: how/if to bring back strict mode for import from xml
 #if 0
 TEST_F(KmlFileTest, TestObjectIdDupeFailing) {
-  std::string errors;
-  const std::string kDupeId("DUPE");
+  string errors;
+  const string kDupeId("DUPE");
   kml_file_->set_strict_parse(true);
   kmldom::ElementPtr root = kml_file_->ParseFromString(
     "<Folder id=\"" + kDupeId + "\">"
@@ -161,9 +160,9 @@ TEST_F(KmlFileTest, TestNullGetSharedStyleById) {
 // Verify a basic shared style is found and a local style is not found.
 TEST_F(KmlFileTest, TestBasicGetSharedStyleById) {
   // Use ParseFromString to insert shared styles into the shared style map.
-  const std::string kStyleId("share-me");
-  const std::string kStyleMapId("me-too");
-  const std::string kFolderStyleId("not-me");
+  const string kStyleId("share-me");
+  const string kStyleMapId("me-too");
+  const string kFolderStyleId("not-me");
   kml_file_ = KmlFile::CreateFromParse(
     "<Document>"
       "<Style id=\"" + kStyleId + "\"/>"
@@ -193,7 +192,7 @@ TEST_F(KmlFileTest, TestBasicGetSharedStyleById) {
 // This is an internal helper function to verify that the passed element
 // is a Placemark with the given name.
 void KmlFileTest::VerifyIsPlacemarkWithName(const ElementPtr& root,
-                                            const std::string& name) {
+                                            const string& name) {
   ASSERT_TRUE(root);
   ASSERT_TRUE(AsPlacemark(root));
   ASSERT_EQ(name, AsPlacemark(root)->get_name());
@@ -201,9 +200,9 @@ void KmlFileTest::VerifyIsPlacemarkWithName(const ElementPtr& root,
 
 // Verify the CreateFromParse() static method using KML data.
 TEST_F(KmlFileTest, TestCreateFromParseOfKml) {
-  const std::string kName("my name");
-  const std::string kKml("<Placemark><name>" + kName + "</name></Placemark>");
-  std::string errors;
+  const string kName("my name");
+  const string kKml("<Placemark><name>" + kName + "</name></Placemark>");
+  string errors;
   kml_file_ = KmlFile::CreateFromParse(kKml, &errors);
   ASSERT_TRUE(errors.empty());
   VerifyIsPlacemarkWithName(kml_file_->get_root(), kName);
@@ -212,15 +211,15 @@ TEST_F(KmlFileTest, TestCreateFromParseOfKml) {
 
 // Verify the CreateFromParse() static method on junk input.
 TEST_F(KmlFileTest, TestCreateFromParseOfJunk) {
-  const std::string kJunk("this is obviously neither KML nor KMZ");
-  std::string errors;
+  const string kJunk("this is obviously neither KML nor KMZ");
+  string errors;
   kml_file_ = KmlFile::CreateFromParse(kJunk, &errors);
 }
 
 // This is an internal helper function to create a KMZ memory buffer for the
 // input KML memory buffer.
-void KmlFileTest::KmlToKmz(const std::string& kml_data,
-                           std::string* kmz_data) {
+void KmlFileTest::KmlToKmz(const string& kml_data,
+                           string* kmz_data) {
   kmlbase::TempFilePtr tempfile = kmlbase::TempFile::CreateTempFile();
   const char* tempname = tempfile->name().c_str();
   ASSERT_TRUE(KmzFile::WriteKmz(tempname, kml_data));
@@ -231,11 +230,11 @@ void KmlFileTest::KmlToKmz(const std::string& kml_data,
 
 // Verify the CreateFromParse() static method using KMZ data.
 TEST_F(KmlFileTest, TestCreateFromParseOfKmz) {
-  const std::string kName("my name");
-  const std::string kKml("<Placemark><name>" + kName + "</name></Placemark>");
-  std::string kmz_data;
+  const string kName("my name");
+  const string kKml("<Placemark><name>" + kName + "</name></Placemark>");
+  string kmz_data;
   KmlToKmz(kKml, &kmz_data);
-  std::string errors;
+  string errors;
   kml_file_ = KmlFile::CreateFromParse(kmz_data, &errors);
   ASSERT_TRUE(errors.empty());
   VerifyIsPlacemarkWithName(kml_file_->get_root(), kName);
@@ -245,10 +244,10 @@ TEST_F(KmlFileTest, TestCreateFromParseOfKmz) {
 // Verify that GetParentLinkParserObservers finds all kinds of parents of
 // links in a KML file.
 TEST_F(KmlFileTest, TestGetLinkParents) {
-  const std::string kAllLinks = std::string(DATADIR) + "/links/alllinks.kml";
-  std::string kml;
+  const string kAllLinks = string(DATADIR) + "/links/alllinks.kml";
+  string kml;
   ASSERT_TRUE(kmlbase::File::ReadFileToString(kAllLinks, &kml));
-  std::string errors;
+  string errors;
   kml_file_ = KmlFile::CreateFromParse(kml, &errors);
   ASSERT_TRUE(errors.empty());
   ASSERT_TRUE(kml_file_);
@@ -264,8 +263,8 @@ TEST_F(KmlFileTest, TestGetLinkParents) {
   ASSERT_EQ(kmldom::Type_Model, link_parents[6]->Type());
 #if 0
   // TODO: handle styleUrl(?) and SchemaData
-  ASSERT_EQ(std::string("style.kml#style"), href_vector[6]->Type());
-  ASSERT_EQ(std::string("#myschema"), href_vector[7]);
+  ASSERT_EQ(string("style.kml#style"), href_vector[6]->Type());
+  ASSERT_EQ(string("#myschema"), href_vector[7]);
 #endif
 }
 
@@ -279,8 +278,8 @@ TEST_F(KmlFileTest, TestConstNull) {
 
 // Verify basic usage of the CreateFromString() static method.
 TEST_F(KmlFileTest, TestBasicCreateFromString) {
-  const std::string kName("my name");
-  const std::string kPlacemark("<Placemark><name>" + kName +
+  const string kName("my name");
+  const string kPlacemark("<Placemark><name>" + kName +
                                "</name></Placemark>");
   kml_file_ = KmlFile::CreateFromString(kPlacemark);
   ASSERT_TRUE(kml_file_);
@@ -288,10 +287,10 @@ TEST_F(KmlFileTest, TestBasicCreateFromString) {
 
 // Verify basic usage of the CreateFromStringWithUrl() static method.
 TEST_F(KmlFileTest, TestBasicCreateFromStringWithUrl) {
-  const std::string kName("my name");
-  const std::string kPlacemark("<Placemark><name>" + kName +
+  const string kName("my name");
+  const string kPlacemark("<Placemark><name>" + kName +
                                "</name></Placemark>");
-  const std::string kUrl("http://foo.com/goo/baz.kml");
+  const string kUrl("http://foo.com/goo/baz.kml");
   // There's no requirement a NetCache need exist.
   kml_file_ = KmlFile::CreateFromStringWithUrl(kPlacemark, kUrl, NULL);
   ASSERT_TRUE(kml_file_);
@@ -307,10 +306,10 @@ TEST_F(KmlFileTest, TestBasicCreateFromStringWithUrl) {
 TEST_F(KmlFileTest, TestCreateWithKmlCache) {
   kmlbase::NetFetcher null_net_fetcher;
   KmlCache kml_cache(&null_net_fetcher, 1);
-  const std::string kName("my name");
-  const std::string kPlacemark("<Placemark><name>" + kName +
+  const string kName("my name");
+  const string kPlacemark("<Placemark><name>" + kName +
                                "</name></Placemark>");
-  const std::string kUrl("http://foo.com/goo/baz.kml");
+  const string kUrl("http://foo.com/goo/baz.kml");
   // Typically the KmlCache is the one that created the KmlFile.
   kml_file_ = KmlFile::CreateFromStringWithUrl(kPlacemark, kUrl, &kml_cache);
   ASSERT_EQ(kUrl, kml_file_->get_url());
@@ -319,15 +318,15 @@ TEST_F(KmlFileTest, TestCreateWithKmlCache) {
 
 // Verify KmlFile's default xmlns is set on the root element.
 TEST_F(KmlFileTest, TestXmlnsOnRoot) {
-  std::string xml;
-  const std::string kExpectedKml(
+  string xml;
+  const string kExpectedKml(
       "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
       "<kml xmlns=\"http://www.opengis.net/kml/2.2\"/>\n");
   kml_file_ = KmlFile::CreateFromString("<kml/>");
   ASSERT_TRUE(kml_file_->SerializeToString(&xml));
   ASSERT_EQ(kExpectedKml, xml);
 
-  const std::string kExpectedPlacemark(
+  const string kExpectedPlacemark(
       "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
       "<Placemark xmlns=\"http://www.opengis.net/kml/2.2\"/>\n");
   kml_file_ = KmlFile::CreateFromString("<Placemark/>");
@@ -341,7 +340,7 @@ TEST_F(KmlFileTest, TestCreateFromImport) {
   ASSERT_FALSE(KmlFile::CreateFromImport(NULL));
   KmlFactory* kml_factory = KmlFactory::GetFactory();
   PlacemarkPtr placemark = kml_factory->CreatePlacemark();
-  const std::string kName("my name");
+  const string kName("my name");
   placemark->set_name(kName);
   KmlPtr kml = KmlFactory::GetFactory()->CreateKml();
   kml->set_feature(placemark);
@@ -366,9 +365,9 @@ TEST_F(KmlFileTest, TestCreateFromImportSerialize) {
   KmlPtr kml = KmlFactory::GetFactory()->CreateKml();
   kml_file_ = KmlFile::CreateFromImport(kml);
   ASSERT_TRUE(kml_file_);
-  std::string xml;
+  string xml;
   ASSERT_TRUE(kml_file_->SerializeToString(&xml));
-  ASSERT_EQ(std::string(
+  ASSERT_EQ(string(
     "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
     "<kml xmlns=\"http://www.opengis.net/kml/2.2\"/>\n"),
     xml);
@@ -378,8 +377,8 @@ TEST_F(KmlFileTest, TestCreateFromImportSerialize) {
 // GetSharedStyleById()
 TEST_F(KmlFileTest, TestCreateFromImportAndGetById) {
   // Use a dom-level parse to create an element hierarchy.
-  const std::string kAllStyles = std::string(DATADIR) + "/style/allstyles.kml";
-  std::string kml;
+  const string kAllStyles = string(DATADIR) + "/style/allstyles.kml";
+  string kml;
   ASSERT_TRUE(kmlbase::File::ReadFileToString(kAllStyles, &kml));
   ElementPtr element = kmldom::Parse(kml, NULL);
   ASSERT_TRUE(element);
@@ -401,13 +400,13 @@ TEST_F(KmlFileTest, TestCreateFromImportLax) {
   KmlFactory* kml_factory = KmlFactory::GetFactory();
   FolderPtr folder = kml_factory->CreateFolder();
   PlacemarkPtr placemark = kml_factory->CreatePlacemark();
-  const std::string kId("some-id-to-duplicate");
-  const std::string kFirstName("first name");
+  const string kId("some-id-to-duplicate");
+  const string kFirstName("first name");
   placemark->set_id(kId);
   placemark->set_name(kFirstName);
   folder->add_feature(placemark);
   placemark = kml_factory->CreatePlacemark();
-  const std::string kLastName("last name");
+  const string kLastName("last name");
   placemark->set_id(kId);
   placemark->set_name(kLastName);
   folder->add_feature(placemark);
@@ -435,9 +434,9 @@ TEST_F(KmlFileTest, TestForSerializeWithNamespaces) {
   kml_file_ = KmlFile::CreateFromString(
       "<Document><gx:Tour><atom:author/></gx:Tour></Document>");
   ASSERT_TRUE(kml_file_);
-  std::string xml;
+  string xml;
   ASSERT_TRUE(kml_file_->SerializeToString(&xml));
-  const std::string kExpected =
+  const string kExpected =
       "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
       "<Document xmlns=\"http://www.opengis.net/kml/2.2\" "
       "xmlns:atom=\"http://www.w3.org/2005/Atom\" "
