@@ -26,7 +26,6 @@
 // This file contains the unit tests for the KmzFile class.
 
 #include "kml/engine/kmz_file.h"
-#include <string>
 #include <vector>
 #include "boost/scoped_ptr.hpp"
 #include "kml/base/file.h"
@@ -54,15 +53,15 @@ class KmzTest : public testing::Test {
 
 TEST_F(KmzTest, TestOpenFromFile) {
   // doc.kmz contains a simple doc.kml and is a valid zip archive.
-  const std::string kGoodKmz = std::string(DATADIR) + "/kmz/doc.kmz";
+  const string kGoodKmz = string(DATADIR) + "/kmz/doc.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kGoodKmz.c_str()));
   ASSERT_TRUE(kmz_file_);
-  std::string kml_data;
+  string kml_data;
   // doc.kml can be read.
   ASSERT_TRUE(kmz_file_->ReadKml(&kml_data));
   ASSERT_FALSE(kml_data.empty());
   // nokml.kmz is a valid zip archive, but does not contain any KML files
-  const std::string kBadKmz = std::string(DATADIR) + "/kmz/nokml.kmz";
+  const string kBadKmz = string(DATADIR) + "/kmz/nokml.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kBadKmz.c_str()));
   ASSERT_TRUE(kmz_file_);
   kml_data.clear();
@@ -74,12 +73,12 @@ TEST_F(KmzTest, TestOpenFromFile) {
 TEST_F(KmzTest, TestOpenFromBadFile) {
   // Two kinds of bad file.
   // 1: a non-existant file:
-  const std::string kNoSuchFile("nosuchfile.kmz");
+  const string kNoSuchFile("nosuchfile.kmz");
   kmz_file_.reset(KmzFile::OpenFromFile(kNoSuchFile.c_str()));
   // The file cannot be opened.
   ASSERT_TRUE(kmz_file_ == NULL);
   // 2: a file that is not a valid KMZ archive.
-  const std::string kBadKmz= std::string(DATADIR) + "/kmz/bad.kmz";
+  const string kBadKmz= string(DATADIR) + "/kmz/bad.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kBadKmz.c_str()));
   // The file could not be read.
   ASSERT_TRUE(kmz_file_ == NULL);
@@ -87,18 +86,18 @@ TEST_F(KmzTest, TestOpenFromBadFile) {
 
 TEST_F(KmzTest, TestOpenFromString) {
   // doc.kmz contains a simple doc.kml and is a valid zip archive.
-  const std::string kGoodKmz = std::string(DATADIR) + "/kmz/doc.kmz";
-  std::string kmz_file_data;
+  const string kGoodKmz = string(DATADIR) + "/kmz/doc.kmz";
+  string kmz_file_data;
   ASSERT_TRUE(File::ReadFileToString(kGoodKmz.c_str(), &kmz_file_data));
   ASSERT_FALSE(kmz_file_data.empty());
   kmz_file_.reset(KmzFile::OpenFromString(kmz_file_data));
   ASSERT_TRUE(kmz_file_);
-  std::string kml_data;
+  string kml_data;
   // doc.kml can be read.
   ASSERT_TRUE(kmz_file_->ReadKml(&kml_data));
   ASSERT_FALSE(kml_data.empty());
   // nokml.kmz is a valid zip archive, but does not contain any KML files
-  const std::string kBadKmz = std::string(DATADIR) + "/kmz/nokml.kmz";
+  const string kBadKmz = string(DATADIR) + "/kmz/nokml.kmz";
   kmz_file_data.clear();
   ASSERT_TRUE(File::ReadFileToString(kBadKmz.c_str(), &kmz_file_data));
   ASSERT_FALSE(kmz_file_data.empty());
@@ -114,15 +113,15 @@ TEST_F(KmzTest, TestReadKml) {
   // doc.kmz has two KML files at the root level, a.kml and doc.kml, which were
   // added to the archive in that order. Assert that a.kml is read instead
   // of doc.kml.
-  const std::string kDoc = std::string(DATADIR) + "/kmz/doc.kmz";
+  const string kDoc = string(DATADIR) + "/kmz/doc.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kDoc.c_str()));
   ASSERT_TRUE(kmz_file_);
-  std::string kml_data;
+  string kml_data;
   ASSERT_TRUE(kmz_file_->ReadKml(&kml_data));
   ASSERT_FALSE(kml_data.empty());
-  ASSERT_TRUE(std::string::npos != kml_data.find("a.kml"));
+  ASSERT_TRUE(string::npos != kml_data.find("a.kml"));
   // nokml.kmz is a valid zip archive, but does not contain any KML files
-  const std::string kNokml = std::string(DATADIR) + "/kmz/nokml.kmz";
+  const string kNokml = string(DATADIR) + "/kmz/nokml.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kNokml.c_str()));
   ASSERT_TRUE(kmz_file_);
   kml_data.clear();
@@ -134,13 +133,13 @@ TEST_F(KmzTest, TestReadKml) {
   // - a/a.kml
   // Each file has a placemark whose <name> is the archived filename.
   // Assert that z/c.kml is read first.
-  const std::string kMulti1 = std::string(DATADIR) + "/kmz/multikml-nodoc.kmz";
+  const string kMulti1 = string(DATADIR) + "/kmz/multikml-nodoc.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kMulti1.c_str()));
   ASSERT_TRUE(kmz_file_);
   kml_data.clear();
   ASSERT_TRUE(kmz_file_->ReadKml(&kml_data));
   ASSERT_FALSE(kml_data.empty());
-  ASSERT_TRUE(std::string::npos != kml_data.find("c.kml"));
+  ASSERT_TRUE(string::npos != kml_data.find("c.kml"));
   // Assert we handle a NULL output string.
   ASSERT_FALSE(kmz_file_->ReadKml(NULL));
 }
@@ -151,12 +150,12 @@ TEST_F(KmzTest, TestReadKmlAndGetPath) {
   // doc.kmz has two KML files at the root level, a.kml and doc.kml, which were
   // added to the archive in that order. Assert that a.kml is read instead
   // of doc.kml.
-  const std::string kDoc = std::string(DATADIR) + "/kmz/doc.kmz";
+  const string kDoc = string(DATADIR) + "/kmz/doc.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kDoc.c_str()));
-  std::string kml_data;
-  std::string kml_path;
+  string kml_data;
+  string kml_path;
   ASSERT_TRUE(kmz_file_->ReadKmlAndGetPath(&kml_data, &kml_path));
-  ASSERT_EQ(std::string("a.kml"), kml_path);
+  ASSERT_EQ(string("a.kml"), kml_path);
   // Verify that a NULL output path arg is well behaved.
   ASSERT_TRUE(kmz_file_->ReadKmlAndGetPath(&kml_data, NULL));
   // multikml-doc.kmz has four kml files added in the following order:
@@ -165,12 +164,12 @@ TEST_F(KmzTest, TestReadKmlAndGetPath) {
   // - a/a.kml
   // - doc/doc.kml
   // Assert that z/c.kml is read because it is the first file in the TOC.
-  const std::string kMulti2 = std::string(DATADIR) + "/kmz/multikml-doc.kmz";
+  const string kMulti2 = string(DATADIR) + "/kmz/multikml-doc.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kMulti2.c_str()));
   ASSERT_TRUE(kmz_file_->ReadKmlAndGetPath(&kml_data, &kml_path));
-  ASSERT_EQ(std::string("z/c.kml"), kml_path);
+  ASSERT_EQ(string("z/c.kml"), kml_path);
   // nokml.kmz is a valid zip archive, but does not contain any KML files
-  const std::string kBadKmz = std::string(DATADIR) + "/kmz/nokml.kmz";
+  const string kBadKmz = string(DATADIR) + "/kmz/nokml.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kBadKmz.c_str()));
   kml_path.clear();
   ASSERT_FALSE(kmz_file_->ReadKmlAndGetPath(&kml_data, &kml_path));
@@ -181,13 +180,13 @@ TEST_F(KmzTest, TestReadKmlAndGetPath) {
 
 TEST_F(KmzTest, TestReadFile) {
   // nokml.kmz has a file called foo.txt in a folder called foo.
-  const std::string kNokml = std::string(DATADIR) + "/kmz/nokml.kmz";
+  const string kNokml = string(DATADIR) + "/kmz/nokml.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kNokml.c_str()));
   ASSERT_TRUE(kmz_file_);
-  std::string file_data;
+  string file_data;
   ASSERT_TRUE(kmz_file_->ReadFile("foo/foo.txt", &file_data));
   ASSERT_FALSE(file_data.empty());
-  std::string tmp = file_data;
+  string tmp = file_data;
   // But does not have a file called bar.txt in that folder
   ASSERT_FALSE(kmz_file_->ReadFile("foo/bar.txt", &file_data));
   // The original data was untouched by this failure.
@@ -199,14 +198,14 @@ TEST_F(KmzTest, TestReadFile) {
 
 TEST_F(KmzTest, TestIsKmz) {
   // Verify that a valid KMZ archive passes IsKmz().
-  const std::string kGoodKmz= std::string(DATADIR) + "/kmz/doc.kmz";
-  std::string kmz_data;
+  const string kGoodKmz= string(DATADIR) + "/kmz/doc.kmz";
+  string kmz_data;
   File::ReadFileToString(kGoodKmz, &kmz_data);
   ASSERT_FALSE(kmz_data.empty());
   ASSERT_TRUE(KmzFile::IsKmz(kmz_data));
 
   // Verify that an invalid KMZ archive fails IsKmz().
-  const std::string kBadKmz= std::string(DATADIR) + "/kmz/bad.kmz";
+  const string kBadKmz= string(DATADIR) + "/kmz/bad.kmz";
   kmz_data.clear();
   File::ReadFileToString(kBadKmz, &kmz_data);
   ASSERT_FALSE(kmz_data.empty());
@@ -218,17 +217,17 @@ TEST_F(KmzTest, TestList) {
   // - z/c.kml
   // - b.kml
   // - a/a.kml
-  const std::string kMulti1 = std::string(DATADIR) + "/kmz/multikml-nodoc.kmz";
+  const string kMulti1 = string(DATADIR) + "/kmz/multikml-nodoc.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kMulti1.c_str()));
   ASSERT_TRUE(kmz_file_);
-  std::vector<std::string> list;
+  std::vector<string> list;
   kmz_file_->List(&list);
   // 3 files were read into the vector.
   ASSERT_TRUE(3 == list.size());
   // They appear in the same order in which they were added.
-  ASSERT_EQ(std::string("z/c.kml"), list[0]);
-  ASSERT_EQ(std::string("b.kml"), list[1]);
-  ASSERT_EQ(std::string("a/a.kml"), list[2]);
+  ASSERT_EQ(string("z/c.kml"), list[0]);
+  ASSERT_EQ(string("b.kml"), list[1]);
+  ASSERT_EQ(string("a/a.kml"), list[2]);
 }
 
 TEST_F(KmzTest, TestWriteKmz) {
@@ -237,11 +236,11 @@ TEST_F(KmzTest, TestWriteKmz) {
   ASSERT_TRUE(tempfile != NULL);
   // Create a KMZ file containing a KML file that is a simple placemark called
   // 'tmp kml'.
-  const std::string kKml("<Placemark><name>tmp kml</name></Placemark>");
+  const string kKml("<Placemark><name>tmp kml</name></Placemark>");
   ASSERT_TRUE(KmzFile::WriteKmz(tempfile->name().c_str(), kKml));
   // Now read the file, ensuring it was properly written.
   ASSERT_TRUE(File::Exists(tempfile->name()));
-  std::string foo;
+  string foo;
   ASSERT_TRUE(File::ReadFileToString(tempfile->name(), &foo));
   ASSERT_FALSE(foo.empty());
   // Open the file into our KmzFile instance and assert the KML was written
@@ -249,7 +248,7 @@ TEST_F(KmzTest, TestWriteKmz) {
   ASSERT_TRUE(File::Exists(tempfile->name().c_str()));
   kmz_file_.reset(KmzFile::OpenFromFile(tempfile->name().c_str()));
   ASSERT_TRUE(kmz_file_);
-  std::string kml_data;
+  string kml_data;
   ASSERT_TRUE(kmz_file_->ReadKml(&kml_data));
   ASSERT_FALSE(kml_data.empty());
   ASSERT_EQ(kKml, kml_data);
@@ -257,9 +256,9 @@ TEST_F(KmzTest, TestWriteKmz) {
 
 // This verifies that a const KmzFile compiles and runs with read methods.
 TEST_F(KmzTest, TestConstKmzFile) {
-  const std::string kDoc = std::string(DATADIR) + "/kmz/doc.kmz";
+  const string kDoc = string(DATADIR) + "/kmz/doc.kmz";
   const KmzFile* kmz_file = KmzFile::OpenFromFile(kDoc.c_str());
-  std::string kml_data;
+  string kml_data;
   ASSERT_TRUE(kmz_file->ReadKml(&kml_data));
   ASSERT_FALSE(kml_data.empty());
   delete kmz_file;
@@ -284,7 +283,7 @@ TEST_F(KmzTest, TestAddFile) {
     KmzFilePtr kmz = KmzFile::Create(tempfile->name().c_str());
     ASSERT_TRUE(kmz);
     // Add three files to the archive.
-    const std::string kNewKml = "<Placemark><name/></Placemark>";
+    const string kNewKml = "<Placemark><name/></Placemark>";
     ASSERT_TRUE(kmz->AddFile(kNewKml, "doc.kml"));
     ASSERT_TRUE(kmz->AddFile(kNewKml, "files/new.kml"));
     ASSERT_TRUE(kmz->AddFile(kNewKml, "other/blah.kml"));
@@ -299,12 +298,12 @@ TEST_F(KmzTest, TestAddFile) {
   // Verify that the archive we created contains the files in order.
   KmzFilePtr created(KmzFile::OpenFromFile(tempfile->name().c_str()));
   ASSERT_TRUE(created);
-  std::vector<std::string> list;
+  std::vector<string> list;
   created->List(&list);
   ASSERT_EQ(static_cast<size_t>(3), list.size());
-  ASSERT_EQ(std::string("doc.kml"), list[0]);
-  ASSERT_EQ(std::string("files/new.kml"), list[1]);
-  ASSERT_EQ(std::string("other/blah.kml"), list[2]);
+  ASSERT_EQ(string("doc.kml"), list[0]);
+  ASSERT_EQ(string("files/new.kml"), list[1]);
+  ASSERT_EQ(string("other/blah.kml"), list[2]);
 }
 
 TEST_F(KmzTest, TestAddFileList) {
@@ -317,9 +316,9 @@ TEST_F(KmzTest, TestAddFileList) {
     ASSERT_TRUE(kmz_file);
 
     // Create a KmlFile from the testdata file.
-    const std::string kBaseDir = File::JoinPaths(std::string(DATADIR), "kmz");
-    const std::string kTestKml = File::JoinPaths(kBaseDir, "doc.kml");
-    std::string kml_data;
+    const string kBaseDir = File::JoinPaths(string(DATADIR), "kmz");
+    const string kTestKml = File::JoinPaths(kBaseDir, "doc.kml");
+    string kml_data;
     ASSERT_TRUE(File::ReadFileToString(kTestKml, &kml_data));
 
     // Gather the local resources used in the KML.
@@ -344,16 +343,16 @@ TEST_F(KmzTest, TestAddFileList) {
   kmlbase::StringVector list;
   created->List(&list);
   ASSERT_EQ(static_cast<size_t>(2), list.size());
-  ASSERT_EQ(std::string("dummy.png"), list[0]);
-  ASSERT_EQ(std::string("kmzfiles/dummy.kml"), list[1]);
+  ASSERT_EQ(string("dummy.png"), list[0]);
+  ASSERT_EQ(string("kmzfiles/dummy.kml"), list[1]);
 }
 
 TEST_F(KmzTest, TestCreateFromElement) {
   kmlbase::TempFilePtr tempfile = kmlbase::TempFile::CreateTempFile();
   ASSERT_TRUE(tempfile != NULL);
-  const std::string kBaseDir = File::JoinPaths(std::string(DATADIR), "kmz");
-  const std::string kTestKml = File::JoinPaths(kBaseDir, "doc.kml");
-  std::string kml_data;
+  const string kBaseDir = File::JoinPaths(string(DATADIR), "kmz");
+  const string kTestKml = File::JoinPaths(kBaseDir, "doc.kml");
+  string kml_data;
   ASSERT_TRUE(File::ReadFileToString(kTestKml, &kml_data));
   KmlFilePtr kml_file =
     KmlFile::CreateFromStringWithUrl(kml_data, kBaseDir, NULL);
@@ -363,38 +362,38 @@ TEST_F(KmzTest, TestCreateFromElement) {
   }
   KmzFilePtr created(KmzFile::OpenFromFile(tempfile->name().c_str()));
   ASSERT_TRUE(created);
-  std::vector<std::string> list;
+  std::vector<string> list;
   created->List(&list);
   ASSERT_EQ(static_cast<size_t>(3), list.size());
-  ASSERT_EQ(std::string("doc.kml"), list[0]);
-  ASSERT_EQ(std::string("dummy.png"), list[1]);
-  ASSERT_EQ(std::string("kmzfiles/dummy.kml"), list[2]);
+  ASSERT_EQ(string("doc.kml"), list[0]);
+  ASSERT_EQ(string("dummy.png"), list[1]);
+  ASSERT_EQ(string("kmzfiles/dummy.kml"), list[2]);
 }
 
 TEST_F(KmzTest, TestCreateFromKmlFilePath) {
   kmlbase::TempFilePtr tempfile = kmlbase::TempFile::CreateTempFile();
   ASSERT_TRUE(tempfile != NULL);
-  const std::string kBaseDir = File::JoinPaths(std::string(DATADIR), "kmz");
-  const std::string kTestKml = File::JoinPaths(kBaseDir, "doc.kml");
+  const string kBaseDir = File::JoinPaths(string(DATADIR), "kmz");
+  const string kTestKml = File::JoinPaths(kBaseDir, "doc.kml");
   {
   ASSERT_TRUE(KmzFile::CreateFromKmlFilepath(kTestKml, tempfile->name()));
   }
   KmzFilePtr created(KmzFile::OpenFromFile(tempfile->name().c_str()));
   ASSERT_TRUE(created);
-  std::vector<std::string> list;
+  std::vector<string> list;
   created->List(&list);
   ASSERT_EQ(static_cast<size_t>(3), list.size());
-  ASSERT_EQ(std::string("doc.kml"), list[0]);
-  ASSERT_EQ(std::string("dummy.png"), list[1]);
-  ASSERT_EQ(std::string("kmzfiles/dummy.kml"), list[2]);
+  ASSERT_EQ(string("doc.kml"), list[0]);
+  ASSERT_EQ(string("dummy.png"), list[1]);
+  ASSERT_EQ(string("kmzfiles/dummy.kml"), list[2]);
 }
 
 TEST_F(KmzTest, TestCreateFromKmlFile) {
   kmlbase::TempFilePtr tempfile = kmlbase::TempFile::CreateTempFile();
   ASSERT_TRUE(tempfile != NULL);
-  const std::string kBaseDir = File::JoinPaths(std::string(DATADIR), "kmz");
-  const std::string kTestKml = File::JoinPaths(kBaseDir, "doc.kml");
-  std::string kml_data;
+  const string kBaseDir = File::JoinPaths(string(DATADIR), "kmz");
+  const string kTestKml = File::JoinPaths(kBaseDir, "doc.kml");
+  string kml_data;
   ASSERT_TRUE(File::ReadFileToString(kTestKml, &kml_data));
   KmlFilePtr kml_file =
     KmlFile::CreateFromStringWithUrl(kml_data, kBaseDir, NULL);
@@ -403,20 +402,20 @@ TEST_F(KmzTest, TestCreateFromKmlFile) {
   }
   KmzFilePtr created(KmzFile::OpenFromFile(tempfile->name().c_str()));
   ASSERT_TRUE(created);
-  std::vector<std::string> list;
+  std::vector<string> list;
   created->List(&list);
   ASSERT_EQ(static_cast<size_t>(3), list.size());
-  ASSERT_EQ(std::string("doc.kml"), list[0]);
-  ASSERT_EQ(std::string("dummy.png"), list[1]);
-  ASSERT_EQ(std::string("kmzfiles/dummy.kml"), list[2]);
+  ASSERT_EQ(string("doc.kml"), list[0]);
+  ASSERT_EQ(string("dummy.png"), list[1]);
+  ASSERT_EQ(string("kmzfiles/dummy.kml"), list[2]);
 }
 
 TEST_F(KmzTest, TestCreateFromGoogleEarthFile) {
   kmlbase::TempFilePtr tempfile = kmlbase::TempFile::CreateTempFile();
   ASSERT_TRUE(tempfile != NULL);
-  const std::string kBaseDir = File::JoinPaths(std::string(DATADIR), "kmz");
-  const std::string kTestKml = File::JoinPaths(kBaseDir, "camels.kml");
-  std::string kml_data;
+  const string kBaseDir = File::JoinPaths(string(DATADIR), "kmz");
+  const string kTestKml = File::JoinPaths(kBaseDir, "camels.kml");
+  string kml_data;
   ASSERT_TRUE(File::ReadFileToString(kTestKml, &kml_data));
   KmlFilePtr kml_file =
     KmlFile::CreateFromStringWithUrl(kml_data, kBaseDir, NULL);
@@ -425,28 +424,28 @@ TEST_F(KmzTest, TestCreateFromGoogleEarthFile) {
   }
   KmzFilePtr created(KmzFile::OpenFromFile(tempfile->name().c_str()));
   ASSERT_TRUE(created);
-  std::vector<std::string> list;
+  std::vector<string> list;
   created->List(&list);
   ASSERT_EQ(static_cast<size_t>(5), list.size());
-  ASSERT_EQ(std::string("doc.kml"), list[0]);
-  ASSERT_EQ(std::string("files/camelbrown200.png"), list[1]);
-  ASSERT_EQ(std::string("files/camelblack200.png"), list[2]);
-  ASSERT_EQ(std::string("files/camera_mode.png"), list[3]);
-  ASSERT_EQ(std::string("files/camelcolor200.png"), list[4]);
+  ASSERT_EQ(string("doc.kml"), list[0]);
+  ASSERT_EQ(string("files/camelbrown200.png"), list[1]);
+  ASSERT_EQ(string("files/camelblack200.png"), list[2]);
+  ASSERT_EQ(string("files/camera_mode.png"), list[3]);
+  ASSERT_EQ(string("files/camelcolor200.png"), list[4]);
 }
 
 TEST_F(KmzTest, TestSaveToString) {
-  const std::string kGoodKmz = std::string(DATADIR) + "/kmz/doc.kmz";
+  const string kGoodKmz = string(DATADIR) + "/kmz/doc.kmz";
 
   kmz_file_.reset(KmzFile::OpenFromFile(kGoodKmz.c_str()));
   ASSERT_TRUE(kmz_file_);
 
-  std::string read_kmz_data;
+  string read_kmz_data;
   ASSERT_TRUE(kmlbase::File::ReadFileToString(kGoodKmz, &read_kmz_data));
   ASSERT_FALSE(read_kmz_data.empty());
 
   ASSERT_FALSE(kmz_file_->SaveToString(NULL));
-  std::string saved_kmz_data;
+  string saved_kmz_data;
   ASSERT_TRUE(kmz_file_->SaveToString(&saved_kmz_data));
   ASSERT_EQ(read_kmz_data, saved_kmz_data);
 }
@@ -454,7 +453,7 @@ TEST_F(KmzTest, TestSaveToString) {
 TEST_F(KmzTest, TestSetGetMaxUncompressedFileSize) {
   const unsigned int kDefaultSize = 2147483647;  // 2 GB.
   const unsigned int kNewSize = 209715200;  // 200 MB.
-  const std::string kGoodKmz = std::string(DATADIR) + "/kmz/doc.kmz";
+  const string kGoodKmz = string(DATADIR) + "/kmz/doc.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kGoodKmz.c_str()));
   ASSERT_TRUE(kmz_file_);
   ASSERT_EQ(kDefaultSize, kmz_file_->get_max_uncompressed_file_size());
@@ -463,7 +462,7 @@ TEST_F(KmzTest, TestSetGetMaxUncompressedFileSize) {
 }
 
 TEST_F(KmzTest, TestMaxUnCompressedSizeExceeded) {
-  const std::string kGoodKmz = std::string(DATADIR) + "/kmz/doc.kmz";
+  const string kGoodKmz = string(DATADIR) + "/kmz/doc.kmz";
   kmz_file_.reset(KmzFile::OpenFromFile(kGoodKmz.c_str()));
   ASSERT_TRUE(kmz_file_);
   const unsigned int kMaxSize = 43;
