@@ -27,7 +27,6 @@
 // functions.
 
 #include "kml/engine/merge.h"
-#include <string>
 #include "kml/dom/kml_funcs.h"
 #include "kml/dom/kml_factory.h"
 #include "kml/dom/kml22.h"
@@ -60,18 +59,18 @@ class MergeTest : public testing::Test {
   }
 
   StylePtr SetSubStyles(StylePtr style, double icon_style_scale,
-                        const std::string& label_style_color,
+                        const string& label_style_color,
                         double line_style_width, bool poly_style_fill,
-                        const std::string& balloon_style_text,
+                        const string& balloon_style_text,
                         kmldom::ListItemTypeEnum liststyle_style_listitemtype);
   void VerifySubStyles(StylePtr style, double icon_style_scale,
-                       const std::string& label_style_color,
+                       const string& label_style_color,
                        double line_style_width, bool poly_style_fill,
-                       const std::string& balloon_style_text,
+                       const string& balloon_style_text,
                        kmldom::ListItemTypeEnum liststyle_style_listitemtype);
-  void SetPointPlacemark(PlacemarkPtr placemark, const std::string& name,
+  void SetPointPlacemark(PlacemarkPtr placemark, const string& name,
                          double lat, double lon);
-  void VerifyPointPlacemark(PlacemarkPtr placemark, const std::string& name,
+  void VerifyPointPlacemark(PlacemarkPtr placemark, const string& name,
                             double lat, double lon);
   KmlFactory *factory_;
   LineStringPtr linestring_;
@@ -94,7 +93,7 @@ TEST_F(MergeTest, TestMergeFieldsNull) {
 TEST_F(MergeTest, TestMergeFieldsSame) {
   // Verify that passing the same element for source and target does not crash.
   MergeFields(source_placemark_, source_placemark_);
-  const std::string kDescription("description");
+  const string kDescription("description");
   source_placemark_->set_description(kDescription);
   MergeFields(source_placemark_, source_placemark_);
   // Placemark is still sane. Placemark had a description before and still
@@ -111,7 +110,7 @@ TEST_F(MergeTest, TestMergeFieldsSame) {
 // Verify normal usage of MergeFields().
 TEST_F(MergeTest, TestSimpleMergeFields) {
   // Set one field in the source.
-  const std::string kSourceName("source name");
+  const string kSourceName("source name");
   source_placemark_->set_name(kSourceName);
   // Merge fields in source to target.
   MergeFields(source_placemark_, target_placemark_);
@@ -119,7 +118,7 @@ TEST_F(MergeTest, TestSimpleMergeFields) {
   ASSERT_EQ(kSourceName, target_placemark_->get_name());
 
   // Set the target's value for the given field.
-  const std::string kTargetName("target name");
+  const string kTargetName("target name");
   target_placemark_->set_name(kTargetName);
   // Verify that the source still has the expected value.
   ASSERT_EQ(kSourceName, source_placemark_->get_name());
@@ -131,10 +130,10 @@ TEST_F(MergeTest, TestSimpleMergeFields) {
 
 // Verify that several fields are properly set in the target.
 TEST_F(MergeTest, TestMergeFieldsMany) {
-  const std::string kName("name");
+  const string kName("name");
   const bool kVisibility(false);
   const bool kOpen(false);
-  const std::string kDescription("name");
+  const string kDescription("name");
   source_placemark_->set_name(kName);
   source_placemark_->set_description(kDescription);
   source_placemark_->set_visibility(kVisibility);
@@ -157,7 +156,7 @@ TEST_F(MergeTest, TestDontMergeComplexChildren) {
   // Give the target a different type for the same complex child.
   target_placemark_->set_geometry(linestring_);
   // Set some simple element children in the source.
-  const std::string kName("hi there");
+  const string kName("hi there");
   source_placemark_->set_name(kName);
   source_placemark_->set_visibility(false);
   // Merge fields from source to target.
@@ -178,7 +177,7 @@ TEST_F(MergeTest, TestMergeElementsNull) {
 }
 
 TEST_F(MergeTest, TestBasicMergeIconStyle) {
-  const std::string kHref("icon.png");
+  const string kHref("icon.png");
   IconStylePtr source = KmlFactory::GetFactory()->CreateIconStyle();
   IconStyleIconPtr icon = KmlFactory::GetFactory()->CreateIconStyleIcon();
   icon->set_href(kHref);
@@ -197,7 +196,7 @@ TEST_F(MergeTest, TestBasicMergeIconStyle) {
 TEST_F(MergeTest, TestMergeIconStyle) {
   const double kScale(1.3);
   const double kHeading(123);
-  const std::string kHref("cool.jpeg");
+  const string kHref("cool.jpeg");
 
   // This is what we are merging in:
   // <Style>
@@ -256,10 +255,10 @@ TEST_F(MergeTest, TestMergeIconStyle) {
 // field to the given value.
 StylePtr MergeTest::SetSubStyles(StylePtr style,
                                  double icon_style_scale,
-                                 const std::string& label_style_color,
+                                 const string& label_style_color,
                                  double line_style_width,
                                  bool poly_style_fill,
-                                 const std::string& balloon_style_text,
+                                 const string& balloon_style_text,
                                  kmldom::ListItemTypeEnum
                                      list_style_listitemtype) {
   // <IconStyle><scale>
@@ -298,10 +297,10 @@ StylePtr MergeTest::SetSubStyles(StylePtr style,
 // This is a utility function to verify the given SubStyle fields.
 void MergeTest::VerifySubStyles(StylePtr style,
                                 double icon_style_scale,
-                                const std::string& label_style_color,
+                                const string& label_style_color,
                                 double line_style_width,
                                 bool poly_style_fill,
-                                const std::string& balloon_style_text,
+                                const string& balloon_style_text,
                                 kmldom::ListItemTypeEnum
                                     list_style_listitemtype) {
   ASSERT_TRUE(style->has_iconstyle());
@@ -333,10 +332,10 @@ void MergeTest::VerifySubStyles(StylePtr style,
 TEST_F(MergeTest, TestMergeFullStyle) {
   // Create a Style with the following SubStyle fields.
   const double kScale(2.2);
-  const std::string kColor("ff112233");
+  const string kColor("ff112233");
   const double kWidth(3.3);
   const bool kFill(false);
-  const std::string kText("This is a <b>bold $[name]</b>");
+  const string kText("This is a <b>bold $[name]</b>");
   const kmldom::ListItemTypeEnum
       kListItemType(kmldom::LISTITEMTYPE_CHECKHIDECHILDREN);
   SetSubStyles(source_style_, kScale, kColor, kWidth, kFill, kText,
@@ -364,7 +363,7 @@ TEST_F(MergeTest, TestMergeFullStyle) {
 
 // This is a utility method to create a Placemark with a Point.
 void MergeTest::SetPointPlacemark(PlacemarkPtr placemark,
-                                  const std::string& name,
+                                  const string& name,
                                   double lat, double lon) {
   placemark->set_name(name);
   PointPtr point = factory_->CreatePoint();
@@ -376,7 +375,7 @@ void MergeTest::SetPointPlacemark(PlacemarkPtr placemark,
 
 // This is a utility method to verify the given fields in a Point Placemark.
 void MergeTest::VerifyPointPlacemark(PlacemarkPtr placemark,
-                                     const std::string& name,
+                                     const string& name,
                                      double lat, double lon) {
   ASSERT_TRUE(placemark->has_name());
   ASSERT_EQ(name, placemark->get_name());
@@ -394,7 +393,7 @@ void MergeTest::VerifyPointPlacemark(PlacemarkPtr placemark,
 
 // This verifies the merge of a Placemark Point element hierarchy.
 TEST_F(MergeTest, TestMergePointPlacemark) {
-  const std::string kName("source");
+  const string kName("source");
   const double kLat(1.1);
   const double kLon(-1.1);
   SetPointPlacemark(source_placemark_, kName, kLat, kLon);
@@ -431,8 +430,8 @@ TEST_F(MergeTest, TestMergeFieldsSerialize) {
 // An early version of MergeElements did not properly preserve the state of
 // previously set attributes.
 TEST_F(MergeTest, TestMergeAttributes) {
-  const std::string kId("style-id");
-  const std::string kTargetId("style-target-id");
+  const string kId("style-id");
+  const string kTargetId("style-target-id");
   source_style_->set_targetid(kTargetId);
   target_style_->set_id(kId);
   MergeElements(source_style_, target_style_);
